/*
  This example code is in the Public Domain (or CC0 licensed, at your option.)
  By Evandro Copercini - 2018

  This example creates a bridge between Serial and Classical Bluetooth (SPP)
  and also demonstrate that SerialBT have the same functionalities of a normal Serial

  Le message est composé de   <<   DG;HB;valeur   >>
  où DG = 'D' pour droite ou 'G' pour gauche, HB = 'H' pour haut ou 'B' pour bas et la valeur est le nombre de points marqués, sans limite ;   0,1,2,3,4  ou  0, 100, 200, 500, 1000  comme tu veux.
  Voici le AIA en PJ
*/

#include "BluetoothSerial.h"
#include "Button2.h"
#include "esp_adc_cal.h"
#include <TFT_eSPI.h> // Graphics and font library for ST7735 driver chip
#include <SPI.h>


#define ADC_EN              14  //ADC_EN is the ADC detection enable port
#define ADC_PIN             34
#define BUTTON_1            35
#define BUTTON_2            0

// New background colour
#define TFT_BROWN 0x38E0

// Pause in milliseconds between screens, change to 0 to time font rendering
#define WAIT 2000

#if !defined(CONFIG_BT_ENABLED) || !defined(CONFIG_BLUEDROID_ENABLED)
#error Bluetooth is not enabled! Please run `make menuconfig` to and enable it
#endif

BluetoothSerial SerialBT;
TFT_eSPI tft = TFT_eSPI();  // Invoke library, pins defined in User_Setup.h

Button2 btn1(BUTTON_1);
Button2 btn2(BUTTON_2);

const unsigned int MAX_MESSAGE_LENGTH = 128;

const int q1 = 27;//2; // ctrl quart q1
const int q2 = 26;//15; // ctrl quart q2
const int q3 = 25;//13; // ctrl quart q3
const int q4 = 33;//12; // ctrl quart q4

const int a1 = 12;//17;//27; // ctrl Anneau A1
const int a2 = 13;//2;//26; // ctrl Anneau A2
const int a3 = 15;//25; // ctrl Anneau A3
const int a4 = 2;//13;//33; // ctrl Anneau A4/
const int a5 = 17;//12;//32; // ctrl Anneau A5

const int buzzer = 32;//17; //controle du buzzer


//const int q1 = 2; // ctrl quart q1
//const int q2 = 15; // ctrl quart q2
//const int q3 = 13; // ctrl quart q3
//const int q4 = 12; // ctrl quart q4

//const int a1 = 27; // ctrl Anneau A1
//const int a2 = 26; // ctrl Anneau A2
//const int a3 = 25; // ctrl Anneau A3
//const int a4 = 33; // ctrl Anneau A4
//const int a5 = 32; // ctrl Anneau A5

//const int buzzer = 17; //controle du buzzer


int nb_char;
int vref = 1100;
int btnCick = false;

int incomingByte = 0; // for incoming serial data
//String recu = "";

int etat_anneau [5][6];

// yves

String cmd="";

bool cadre = false;

int val_point = 2 ;             // definir le coefficient de multiplication du point, il est toujour pair
                                // le résultat renvoyé sera le n° de l'anneau * par cette valeur
char dg = ' ';                 // position à droite ou à gauche par rapport au centre de la cible
char hb = ' ';                 // position en haut ou en bas par rapport au centre de la cible
int point;                     // point marqué (0 si hors cible, 1 pour anneau ext. 2,3, et 4 pour centre de cible)

int nb_secteur_en_contact = 0;



void setup() {
  // toutes les bornes sont en mode entrée résistances de tirage au plus
  pinMode(q1, INPUT_PULLUP);
  pinMode(q2, INPUT_PULLUP);
  pinMode(q3, INPUT_PULLUP);
  pinMode(q4, INPUT_PULLUP);
  pinMode(a1, INPUT_PULLUP);
  pinMode(a2, INPUT_PULLUP);
  pinMode(a3, INPUT_PULLUP);
  pinMode(a4, INPUT_PULLUP);
  pinMode(a5, INPUT_PULLUP);

  pinMode(buzzer, OUTPUT); // le buzzer est cablé ente le +3v et lsa sortie 17. La sortie à 1 il ne fonctionne pas, la sortie à 0 il buzz
                            // de cette maniere, on entend un petit bit à la mise sous tension

  Serial.begin(115200);
  SerialBT.begin("ESP32_TTGO_OLED"); //Bluetooth device name
  Serial.println("The device started, now you can pair it with bluetooth!");

  pinMode(ADC_EN, OUTPUT);
  digitalWrite(ADC_EN, HIGH);

  tft.init();
  tft.setRotation(3); // 0 usb en bas ;1 usb à droite; 2 usb en haut ; 3 usb a gauche


  // tft.setTextSize(4);
  tft.setTextFont(4);
  tft.fillScreen(TFT_BLACK);
  tft.setTextColor(TFT_WHITE, TFT_BLACK);
  tft.setCursor(10, 10);

 // button_init();

  esp_adc_cal_characteristics_t adc_chars;
  esp_adc_cal_value_t val_type = esp_adc_cal_characterize(ADC_UNIT_1, ADC_ATTEN_DB_11, ADC_WIDTH_BIT_12, 1100, &adc_chars);    //Check type of calibration value used to characterize ADC
  if (val_type == ESP_ADC_CAL_VAL_EFUSE_VREF) {
    Serial.printf("eFuse Vref:%u mV", adc_chars.vref);
    vref = adc_chars.vref;
  } else if (val_type == ESP_ADC_CAL_VAL_EFUSE_TP) {
    Serial.printf("Two Point --> coeff_a:%umV coeff_b:%umV\n", adc_chars.coeff_a, adc_chars.coeff_b);
  } else {
    Serial.println("Default Vref: 1100mV");
  }
  //Affiche_Cadre ();
  digitalWrite(buzzer,LOW);
  delay(100);
  digitalWrite(buzzer,HIGH);
}


void loop() {
  /*
    while (Serial.available() > 0)
    {
    recoie_serial();
    }
    while (SerialBT.available() > 0)
    {
    btnCick = false;
    recoie_bt();
    }
  */
  /*
     showVoltage();
    if (btnCick) {
    btnCick = false;
  */
  //test_secteur();
 // delay(10);

 // Affiche_Donnees ();
 // delay(10);
  /*
    showVoltage();
    // }
    button_loop();
    btn1.loop();
    btn2.loop();

  */
 // digitalWrite(buzzer, digitalRead(a3));

 trt_command();          // appel bluetoot
 delay(10);
}







/*
    void loop() {
    if (Serial.available()) {
      SerialBT.write(Serial.read());
      tft.print("test 1")
    }
    if (SerialBT.available()) {
      Serial.write(SerialBT.read());
    }
    delay(20);

    }
*/
